@@ -21,7 +21,6 @@ struct _charpick_data {
   gchar selected_char;
   gint last_index;
   GtkWidget *box;
-  GtkWidget *event_box;
   GtkWidget *frame;
   GtkWidget *applet;
   GtkToggleButton *last_toggle_button;
@@ -44,6 +43,8 @@ void start_callback_update();
 
 void build_table(charpick_data *curr_data);
 void property_show(BonoboUIComponent *uic, gpointer data, const gchar *verbname);
+void set_atk_name_description(GtkWidget *widget, const gchar *name,
+                              const gchar *description);
 
 
 
