@@ -159,7 +159,7 @@ static void
 gkb_prop_map_help_clicked (GkbMapDialogInfo * mdi)
 {
 	GError *error = NULL;
-        gnome_help_display("gkb","gkb-prefs-edit",&error);
+        gnome_help_display("gkb","gkb-edit-layout",&error);
 }
 
 
@@ -338,7 +338,7 @@ gkb_prop_map_get_arquitectures (GkbPropertyBoxInfo * pbi)
   GList *list = NULL;
 
   list = g_list_prepend (list, _("ix86"));
-  list = g_list_prepend (list, _("sun"));
+  list = g_list_prepend (list, _("Sun"));
   list = g_list_prepend (list, _("mac"));
   list = g_list_prepend (list, _("sgi"));
   list = g_list_prepend (list, _("dec"));
