@@ -1,4 +1,4 @@
-/* $Id: gweather-applet.c,v 1.47 2002/05/14 20:52:07 kevinv Exp $ */
+/* $Id: gweather-applet.c,v 1.48 2002/05/20 20:37:53 kevinv Exp $ */
 
 /*
  *  Papadimitriou Spiros <spapadim+@cs.cmu.edu>
@@ -171,9 +171,9 @@ void gweather_applet_create (GWeatherApplet *gw_applet)
     gw_applet->gweather_pref.detailed = FALSE;
     gw_applet->gweather_pref.radar_enabled = TRUE;
     
-#if 0   
+ 
     gnome_window_icon_set_default_from_file (GNOME_ICONDIR"/gweather/tstorm.xpm");
-#endif
+
     /* PUSH */
     gtk_widget_push_colormap (gdk_rgb_get_cmap ());
 
@@ -190,10 +190,7 @@ void gweather_applet_create (GWeatherApplet *gw_applet)
 
     gtk_signal_connect (GTK_OBJECT(gw_applet->applet), "button_press_event",
                        GTK_SIGNAL_FUNC(clicked_cb), gw_applet);
-
-    g_signal_connect (G_OBJECT(gw_applet->applet), "destroy",
-                        G_CALLBACK(gtk_main_quit), NULL);
-                        
+                     
     tooltips = gtk_tooltips_new();
 
     gtk_tooltips_set_tip(tooltips, GTK_WIDGET(gw_applet->applet), _("GNOME Weather"), NULL);
