@@ -15,6 +15,10 @@
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  */
 
+#ifdef HAVE_CONFIG_H
+#include <config.h>
+#endif
+
 #include <libbonobo.h>
 #include <libgnome/libgnome.h>
 #include <libgnomeui/libgnomeui.h>
@@ -42,11 +46,11 @@
 
 static const gchar *links_menu_xml =
 	"    <placeholder name=\"ChildItem\">\n"
-	"        <menuitem name=\"Action\" verb=\"Action\" label=\"Rename %s...\"\n"
+	"        <menuitem name=\"Action\" verb=\"Action\" label=\"Rename %s _Menu...\"\n"
 	"                  pixtype=\"stock\" pixname=\"gtk-convert\"/>\n"
-	"        <menuitem name=\"Regenerate\" verb=\"Regenerate\" label=\"Regenerate %s\"\n"
+	"        <menuitem name=\"Regenerate\" verb=\"Regenerate\" label=\"_Regenerate %s\"\n"
 	"                  pixtype=\"stock\" pixname=\"gtk-refresh\"/>\n"
-	"        <menuitem name=\"Remove\" verb=\"Remove\" label=\"Remove %s\"\n"
+	"        <menuitem name=\"Remove\" verb=\"Remove\" label=\"R_emove %s\"\n"
 	"                  pixtype=\"stock\" pixname=\"gtk-close\"/>\n"
 	"        <separator/>"
 	"    </placeholder>";
@@ -93,7 +97,7 @@ panel_menu_links_new_with_id (PanelMenu *parent, gint id)
 	gchar *base_key;
 	gchar *dir_key;
 	GConfClient *client;
-	gchar *name;
+	gchar *name = NULL;
 
 	if (id > object_counter)
 		object_counter = id;
@@ -264,8 +268,8 @@ panel_menu_links_get_widget (PanelMenuEntry *entry)
 {
 	PanelMenuLinks *links;
 
-	g_return_if_fail (entry != NULL);
-	g_return_if_fail (entry->type == PANEL_MENU_TYPE_LINKS);
+	g_return_val_if_fail (entry != NULL, NULL);
+	g_return_val_if_fail (entry->type == PANEL_MENU_TYPE_LINKS, NULL);
 
 	links = (PanelMenuLinks *) entry->data;
 	return (links->links);
@@ -334,6 +338,8 @@ panel_menu_links_append_item (PanelMenuEntry *entry, gchar *uri)
 			menuitem = GTK_MENU (submenu)->parent_menu_item;
 			panel_menu_path_load ((const gchar *) uri,
 					      GTK_MENU_SHELL (submenu));
+			panel_menu_path_monitor ((const gchar *) uri,
+						 GTK_MENU_ITEM (menuitem));
 			retval = TRUE;
 		}
 	}
@@ -342,6 +348,8 @@ panel_menu_links_append_item (PanelMenuEntry *entry, gchar *uri)
 		links->links_list =
 			g_list_append (links->links_list, g_strdup (uri));
 	}
+
+	return retval;
 }
 
 static gint
@@ -393,7 +401,7 @@ panel_menu_links_new_with_dialog (PanelMenu *panel_menu)
 
 	dialog = panel_menu_common_single_entry_dialog_new (_
 							    ("Create links item..."),
-							    _("Name:"),
+							    _("_Name:"),
 							    _("Shortcuts"),
 							    &name_entry);
 	gtk_widget_show (dialog);
@@ -429,7 +437,7 @@ rename_links_cb (GtkWidget *widget, PanelMenuEntry *entry)
 
 	dialog = panel_menu_common_single_entry_dialog_new (_
 							    ("Rename links item..."),
-							    _("Name:"),
+							    _("_Name:"),
 							    links->name,
 							    &name_entry);
 	gtk_widget_show (dialog);
@@ -455,14 +463,17 @@ panel_menu_links_save_config (PanelMenuEntry *entry)
 	gchar *id;
 	gchar *key;
 
-	g_return_if_fail (entry != NULL);
-	g_return_if_fail (entry->type == PANEL_MENU_TYPE_LINKS);
+	g_return_val_if_fail (entry != NULL, NULL);
+	g_return_val_if_fail (entry->type == PANEL_MENU_TYPE_LINKS, NULL);
 
 	panel_menu = entry->parent;
 	applet = panel_menu->applet;
 	links = (PanelMenuLinks *) entry->data;
 
 	id = g_strdup_printf ("links%d", links->id);
+	key = g_strdup_printf ("%s/name", id);
+	panel_applet_gconf_set_string (applet, key, links->name, NULL);
+	g_free (key);
 	key = g_strdup_printf ("%s/links-list", id);
 	panel_applet_gconf_set_string_list (applet, key, links->links_list);
 	g_free (key);
